@@ -23,11 +23,13 @@
 #include "active-sensor.h"
 
 void active_sensor_libnotify_notify(ActiveSensor *active_sensor,
+                                    NotifType notif_type,
                                     const gchar *summary,
                                     const gchar *message,
                                     const gchar *icon_filename,
                                     gint timeout_msecs,
                                     GtkWidget *attach);
-void active_sensor_libnotify_notify_end(ActiveSensor *active_sensor);
+void active_sensor_libnotify_notify_end(ActiveSensor *active_sensor,
+                                        NotifType notif_type);
 
 #endif /* SENSORS_APPLET_LIBNOTIFY_H */
