@@ -29,6 +29,8 @@
 /* always list current version */
 static const gchar * const compatible_versions[] = {
         PACKAGE_VERSION,
+        "1.7.11",
+        "1.7.10",
         "1.7.9",
         "1.7.8",
         "1.7.7",
@@ -209,6 +211,8 @@ void sensors_applet_gconf_setup(SensorsApplet *sensors_applet) {
                         g_free(old_version);
 
                 }
+                sensors_applet_notify(sensors_applet, GCONF_READ_ERROR);
+                
                         
                 sensors_applet_gconf_error_occurred(SENSORS_APPLET_VERSION_ERROR);
         }
@@ -331,6 +335,8 @@ gboolean sensors_applet_gconf_setup_sensors(SensorsApplet *sensors_applet) {
                                                        key_types[i], 
                                                        &error);
                 if (error || NULL == lists[i]) {
+                        sensors_applet_notify(sensors_applet, GCONF_READ_ERROR);
+                
                         sensors_applet_gconf_error_occurred(SENSORS_APPLET_GCONF_ERROR);
                         if (error) {
                                 g_error_free(error);
@@ -468,6 +474,8 @@ gboolean sensors_applet_gconf_save_sensors(SensorsApplet *sensors_applet) {
                                                     key_types[i],
                                                     lists[i], &error);
                         if (error) {
+                                sensors_applet_notify(sensors_applet, GCONF_WRITE_ERROR);
+                
                                 g_error_free(error);
                                 return FALSE;
                         }
