@@ -61,9 +61,12 @@
 				     * only do ints easily */
 #define ALARM_ENABLES "alarm_enables" /* list of whether each sensor
 				       * has its alarm enabled */
-#define ALARM_COMMANDS "alarm_commands" /* list of commands to execute
-					 * when each alarm is
-					 * activated */
+#define LOW_ALARM_COMMANDS "low_alarm_commands" /* list of commands to execute
+                                                 * when each alarm is
+                                                 * activated */
+#define HIGH_ALARM_COMMANDS "high_alarm_commands" /* list of commands to execute
+                                                 * when each alarm is
+                                                 * activated */
 
 #define ALARM_TIMEOUTS "alarm_timeouts" /* list of how often each
 					   alarm should be sounded (in
