@@ -26,6 +26,10 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#ifdef HAVE_LIBNOTIFY
+#include <libnotify/notify.h>
+#endif
+
 typedef struct _SensorsApplet SensorsApplet;
 typedef struct _ActiveSensor ActiveSensor;
 
@@ -162,10 +166,13 @@ typedef enum {
         FAHRENHEIT
 } TemperatureScale;
 
-/* two types of Notifs - low and high alarms */
+/* types of Notifs - low and high alarm warnings and error conditions*/
 typedef enum {
         LOW_ALARM = 0,
         HIGH_ALARM,
+        SENSOR_INTERFACE_ERROR,
+        GCONF_READ_ERROR,
+        GCONF_WRITE_ERROR,
         NUM_NOTIFS
 } NotifType;
 
@@ -198,6 +205,9 @@ struct _SensorsApplet {
 	GtkWidget *table;
 	GList *active_sensors;
 	GtkTooltips *tooltips;
+#ifdef HAVE_LIBNOTIFY
+        NotifyNotification *notification;
+#endif // HAVE_LIBNOTIFY
 };
 
 
@@ -258,10 +268,11 @@ void sensors_applet_reorder_sensors(SensorsApplet *sensors_applet);
 gdouble sensors_applet_convert_temperature(gdouble value, 
                                            TemperatureScale old, 
                                            TemperatureScale new);
-
+void sensors_applet_notify(SensorsApplet *sensors_applet,
+                           NotifType notif_type);
 void sensors_applet_notify_end(ActiveSensor *active_sensor, NotifType notif_type);
 void sensors_applet_notify_end_all(SensorsApplet *sensors_applet);
-void sensors_applet_notify(ActiveSensor *active_sensor, NotifType notif_type);
+void sensors_applet_notify_active_sensor(ActiveSensor *active_sensor, NotifType notif_type);
 GdkPixbuf *sensors_applet_load_icon(IconType icon_type);
 void sensors_applet_graph_size_changed(SensorsApplet *sensors_applet);
 
